@@ -8,6 +8,7 @@ use crate::format::{get_coord_index, get_job_index};
 use crate::utils::combine_error_results;
 use hashbrown::HashSet;
 use std::cmp::Ordering;
+use vrp_core::construction::clustering::vicinity::ServingPolicy;
 use vrp_core::utils::compare_floats;
 
 /// Checks assignment of jobs and vehicles.
@@ -162,25 +163,74 @@ fn check_jobs_match(ctx: &CheckerContext) -> Result<(), String> {
             tour.stops.iter().flat_map(move |stop| {
                 stop.activities
                     .iter()
-                    .filter(move |activity| {
-                        let result = try_match_job(
-                            tour,
-                            stop,
-                            activity,
-                            get_job_index(&ctx.core_problem),
-                            get_coord_index(&ctx.core_problem),
-                        );
+                    .enumerate()
+                    .filter({
+                        move |(idx, activity)| {
+                            let result = try_match_job(
+                                tour,
+                                stop,
+                                activity,
+                                get_job_index(&ctx.core_problem),
+                                get_coord_index(&ctx.core_problem),
+                            );
+                            let not_equal = |left: f64, right: f64| compare_floats(left, right) != Ordering::Equal;
 
-                        match result {
-                            Err(_) => true,
-                            Ok(Some(JobInfo(_, _, place, time))) => {
-                                let expected_departure = time.start.max(place.time.start) + place.duration;
-                                compare_floats(time.end, expected_departure) != Ordering::Equal
+                            match result {
+                                Err(_) => true,
+                                Ok(Some(JobInfo(_, _, place, time))) => {
+                                    let parking = ctx
+                                        .clustering
+                                        .as_ref()
+                                        .map(|config| config.serving.get_parking())
+                                        .unwrap_or(0.);
+                                    let commute_profile = ctx.clustering.as_ref().map(|config| config.profile.clone());
+                                    let domain_commute = ctx.get_commute_info(commute_profile, parking, stop, *idx);
+
+                                    match (&ctx.clustering, &activity.commute, domain_commute) {
+                                        (_, _, Err(_))
+                                        | (_, None, Ok(Some(_)))
+                                        | (_, Some(_), Ok(None))
+                                        | (&None, &Some(_), Ok(Some(_))) => true,
+                                        (_, None, Ok(None)) => {
+                                            let expected_departure = time.start.max(place.time.start) + place.duration;
+                                            not_equal(time.end, expected_departure)
+                                        }
+                                        (Some(config), Some(commute), Ok(Some(d_commute))) => {
+                                            let (service_time, parking) = match config.serving {
+                                                ServingPolicy::Original { parking } => (place.duration, parking),
+                                                ServingPolicy::Multiplier { multiplier, parking } => {
+                                                    (place.duration * multiplier, parking)
+                                                }
+                                                ServingPolicy::Fixed { value, parking } => (value, parking),
+                                            };
+
+                                            let a_commute = commute.to_domain(&ctx.coord_index);
+
+                                            // NOTE: we keep parking in service time of a first activity of the non-first cluster
+                                            let service_time = service_time
+                                                + if a_commute.is_zero_distance() && *idx > 0 { parking } else { 0. };
+
+                                            let expected_departure = time.start.max(place.time.start)
+                                                + service_time
+                                                + d_commute.backward.duration;
+                                            let actual_departure = time.end + d_commute.backward.duration;
+
+                                            // NOTE: a "workaroundish" approach for two clusters in the same stop
+                                            (not_equal(actual_departure, expected_departure)
+                                                && not_equal(actual_departure, expected_departure - parking))
+                                                // compare commute
+                                                || not_equal(a_commute.forward.distance, d_commute.forward.distance)
+                                                || not_equal(a_commute.forward.duration, d_commute.forward.duration)
+                                                || not_equal(a_commute.backward.distance, d_commute.backward.distance)
+                                                || not_equal(a_commute.backward.duration, d_commute.backward.duration)
+                                        }
+                                    }
+                                }
+                                _ => false,
                             }
-                            _ => false,
                         }
                     })
-                    .map(|activity| {
+                    .map(|(_, activity)| {
                         format!(
                             "{}:{}",
                             activity.job_id.clone(),
