@@ -3,15 +3,16 @@
 //!
 
 extern crate serde_json;
+
+use hashbrown::HashMap;
 use serde::{Deserialize, Serialize};
+use std::fmt;
 use std::io::BufWriter;
 use vrp_core::models::problem::Job as CoreJob;
 use vrp_core::models::Problem as CoreProblem;
 
 mod coord_index;
-pub(crate) use self::coord_index::CoordIndex;
-use hashbrown::HashMap;
-use std::fmt;
+pub use self::coord_index::CoordIndex;
 
 pub mod problem;
 pub mod solution;
