@@ -120,14 +120,107 @@ pub struct Job {
     pub group: Option<String>,
 }
 
+// region Clustering
+
+/// Specifies clustering algorithm.
+#[derive(Clone, Deserialize, Debug, Serialize)]
+#[serde(tag = "type")]
+pub enum Clustering {
+    /// Vicinity clustering.
+    #[serde(rename(deserialize = "vicinity", serialize = "vicinity"))]
+    Vicinity {
+        /// Specifies a vehicle profile used to calculate commute duration and distance between
+        /// activities in the single stop.
+        profile: VehicleProfile,
+        /// Specifies threshold information.
+        threshold: VicinityThresholdPolicy,
+        /// Specifies visiting policy.
+        visiting: VicinityVisitPolicy,
+        /// Specifies service time policy.
+        serving: VicinityServingPolicy,
+        /// Specifies filtering policy.
+        filtering: Option<VicinityFilteringPolicy>,
+    },
+}
+
+/// Defines a various thresholds to control cluster size.
+#[derive(Clone, Deserialize, Debug, Serialize)]
+#[serde(rename_all = "camelCase")]
+pub struct VicinityThresholdPolicy {
+    /// Moving duration limit.
+    pub duration: f64,
+    /// Moving distance limit.
+    pub distance: f64,
+    /// Minimum shared time for jobs (non-inclusive).
+    pub min_shared_time: Option<f64>,
+    /// The smallest time window of the cluster after service time shrinking.
+    pub smallest_time_window: Option<f64>,
+    /// The maximum amount of jobs per cluster.
+    pub max_jobs_per_cluster: Option<usize>,
+}
+
+/// Specifies cluster visiting policy.
+#[derive(Clone, Deserialize, Debug, Serialize)]
+#[serde(rename_all = "camelCase")]
+pub enum VicinityVisitPolicy {
+    /// It is required to return to the first job's location (cluster center) before visiting a next job.
+    Return,
+    /// Clustered jobs are visited one by one from the cluster center finishing in the end at the
+    /// first job's location.
+    Continue,
+}
+
+/// Specifies service time policy.
+#[derive(Clone, Deserialize, Debug, Serialize)]
+#[serde(tag = "type")]
+pub enum VicinityServingPolicy {
+    /// Keep original service time.
+    #[serde(rename(deserialize = "original", serialize = "original"))]
+    Original {
+        /// Parking time.
+        parking: f64,
+    },
+    /// Correct service time by some multiplier.
+    #[serde(rename(deserialize = "multiplier", serialize = "multiplier"))]
+    Multiplier {
+        /// Multiplier value applied to original job's duration.
+        value: f64,
+        /// Parking time.
+        parking: f64,
+    },
+    /// Use fixed value for all clustered jobs.
+    #[serde(rename(deserialize = "fixed", serialize = "fixed"))]
+    Fixed {
+        /// Fixed value used for all jobs in the cluster.
+        value: f64,
+        /// Parking time.
+        parking: f64,
+    },
+}
+
+/// Specifies filtering policy for vicinity clustering.
+#[derive(Clone, Deserialize, Debug, Serialize)]
+#[serde(rename_all = "camelCase")]
+pub struct VicinityFilteringPolicy {
+    /// Ids of the jobs which cannot be used within clustering.
+    pub exclude_job_ids: Vec<String>,
+}
+
+// endregion
+
 /// A plan specifies work which has to be done.
 #[derive(Clone, Deserialize, Debug, Serialize)]
 pub struct Plan {
     /// List of jobs.
     pub jobs: Vec<Job>,
+
     /// List of relations between jobs and vehicles.
     #[serde(skip_serializing_if = "Option::is_none")]
     pub relations: Option<Vec<Relation>>,
+
+    /// Specifies clustering parameters.
+    #[serde(skip_serializing_if = "Option::is_none")]
+    pub clustering: Option<Clustering>,
 }
 
 // endregion
