@@ -3,19 +3,19 @@
 mod objective_reader_test;
 
 use crate::core::models::common::ValueDimension;
+use crate::core::models::problem::Job;
 use crate::format::problem::reader::{ApiProblem, ProblemProperties};
 use crate::format::problem::BalanceOptions;
+use crate::format::problem::Objective::TourOrder as FormatTourOrder;
 use crate::format::problem::Objective::*;
 use crate::format::TOUR_ORDER_CONSTRAINT_CODE;
 use std::sync::Arc;
+use vrp_core::construction::clustering::vicinity::ClusterDimension;
 use vrp_core::construction::constraints::{ConstraintPipeline, FleetUsageConstraintModule};
 use vrp_core::models::common::{MultiDimLoad, SingleDimLoad};
 use vrp_core::models::problem::{ObjectiveCost, Single, TargetConstraint, TargetObjective};
-use vrp_core::solver::objectives::*;
-
-use crate::core::models::problem::Job;
-use crate::format::problem::Objective::TourOrder as FormatTourOrder;
 use vrp_core::solver::objectives::TourOrder as CoreTourOrder;
+use vrp_core::solver::objectives::*;
 
 pub fn create_objective(
     api_problem: &ApiProblem,
@@ -50,11 +50,9 @@ pub fn create_objective(
                         }
                         MinimizeUnassignedJobs { breaks } => {
                             if let Some(breaks) = *breaks {
-                                core_objectives.push(Arc::new(TotalUnassignedJobs::new(Arc::new(move |_, job, _| {
-                                    get_job_as_break_estimate(job, breaks, 1.)
-                                }))))
+                                core_objectives.push(Arc::new(get_unassigned_objective(breaks)))
                             } else {
-                                core_objectives.push(Arc::new(TotalUnassignedJobs::default()))
+                                core_objectives.push(Arc::new(get_unassigned_objective(1.)))
                             }
                         }
                         BalanceMaxLoad { options } => {
@@ -96,12 +94,8 @@ pub fn create_objective(
             constraint.add_module(value_module);
             constraint.add_module(Arc::new(FleetUsageConstraintModule::new_minimized()));
 
-            let mut objectives = vec![
-                vec![value_objective],
-                vec![Arc::new(TotalUnassignedJobs::default())],
-                vec![Arc::new(TotalRoutes::default())],
-                vec![TotalCost::minimize()],
-            ];
+            let mut objectives =
+                std::iter::once(vec![value_objective]).chain(get_default_objectives().into_iter()).collect::<Vec<_>>();
 
             if has_order {
                 let (order_module, order_objective) = get_order(false);
@@ -115,18 +109,14 @@ pub fn create_objective(
             let (order_module, order_objective) = get_order(false);
             constraint.add_module(order_module);
 
-            let mut objectives: Vec<Vec<TargetObjective>> = vec![
-                vec![Arc::new(TotalUnassignedJobs::default())],
-                vec![Arc::new(TotalRoutes::default())],
-                vec![TotalCost::minimize()],
-            ];
+            let mut objectives = get_default_objectives();
             objectives.insert(1, vec![order_objective]);
 
             ObjectiveCost::new(objectives)
         }
         _ => {
             constraint.add_module(Arc::new(FleetUsageConstraintModule::new_minimized()));
-            ObjectiveCost::default()
+            ObjectiveCost::new(get_default_objectives())
         }
     })
 }
@@ -146,9 +136,18 @@ fn get_value(
         max_value,
         reduction_factor.unwrap_or(0.1),
         Arc::new(move |solution| {
-            solution.unassigned.iter().map(|(job, _)| get_job_as_break_estimate(job, break_value, 0.)).sum()
+            solution.unassigned.iter().map(|(job, _)| get_unassigned_job_estimate(job, break_value, 0.)).sum()
         }),
         Arc::new(|job| job.dimens().get_value::<f64>("value").cloned().unwrap_or(0.)),
+        Arc::new(|job, value| match job {
+            Job::Single(single) => {
+                let mut dimens = single.dimens.clone();
+                dimens.set_value("value", value);
+
+                Job::Single(Arc::new(Single { places: single.places.clone(), dimens }))
+            }
+            _ => job.clone(),
+        }),
     )
 }
 
@@ -191,12 +190,28 @@ fn get_load_balance(
     }
 }
 
-fn get_job_as_break_estimate(job: &Job, break_value: f64, default_value: f64) -> f64 {
-    job.dimens().get_value::<String>("type").map_or(default_value, |job_type| {
-        if job_type == "break" {
-            break_value
-        } else {
-            default_value
-        }
-    })
+fn get_default_objectives() -> Vec<Vec<TargetObjective>> {
+    vec![
+        vec![Arc::new(get_unassigned_objective(1.))],
+        vec![Arc::new(TotalRoutes::default())],
+        vec![TotalCost::minimize()],
+    ]
+}
+
+fn get_unassigned_objective(break_value: f64) -> TotalUnassignedJobs {
+    TotalUnassignedJobs::new(Arc::new(move |_, job, _| get_unassigned_job_estimate(job, break_value, 1.)))
+}
+
+fn get_unassigned_job_estimate(job: &Job, break_value: f64, default_value: f64) -> f64 {
+    if let Some(clusters) = job.dimens().get_cluster() {
+        clusters.len() as f64 * default_value
+    } else {
+        job.dimens().get_value::<String>("type").map_or(default_value, |job_type| {
+            if job_type == "break" {
+                break_value
+            } else {
+                default_value
+            }
+        })
+    }
 }
