@@ -1,6 +1,10 @@
-use crate::format::Location;
+use crate::format::{CoordIndex, Location};
+use crate::{format_time, parse_time};
 use serde::{Deserialize, Serialize};
 use std::io::{BufReader, BufWriter, Error, Read, Write};
+use vrp_core::models::common::{Duration, Timestamp};
+use vrp_core::models::solution::Commute as DomainCommute;
+use vrp_core::models::solution::CommuteInfo as DomainCommuteInfo;
 
 /// Timing statistic.
 #[derive(Clone, Deserialize, Serialize, PartialEq, Debug)]
@@ -14,6 +18,12 @@ pub struct Timing {
     /// Break time.
     #[serde(rename(serialize = "break", deserialize = "break"))]
     pub break_time: i64,
+    /// Commuting time.
+    #[serde(default = "i64::default")]
+    pub commuting: i64,
+    /// Parking time.
+    #[serde(default = "i64::default")]
+    pub parking: i64,
 }
 
 /// Represents statistic.
@@ -47,6 +57,28 @@ pub struct Interval {
     pub end: String,
 }
 
+/// Stores information about commuting to perform activity.
+#[derive(Clone, Deserialize, Serialize, PartialEq, Debug)]
+pub struct Commute {
+    /// Commuting to the activity place.
+    #[serde(skip_serializing_if = "Option::is_none")]
+    pub forward: Option<CommuteInfo>,
+    /// Commuting from the activity place.
+    #[serde(skip_serializing_if = "Option::is_none")]
+    pub backward: Option<CommuteInfo>,
+}
+
+/// Stores information about commuting information in one direction.
+#[derive(Clone, Deserialize, Serialize, PartialEq, Debug)]
+pub struct CommuteInfo {
+    /// Commute location.
+    pub location: Location,
+    /// Travelled distance.
+    pub distance: f64,
+    /// Travel time.
+    pub time: Interval,
+}
+
 /// An activity is unit of work performed at some place.
 #[derive(Clone, Deserialize, Serialize, PartialEq, Debug)]
 #[serde(rename_all = "camelCase")]
@@ -59,12 +91,15 @@ pub struct Activity {
     /// Location.
     #[serde(skip_serializing_if = "Option::is_none")]
     pub location: Option<Location>,
-    /// Active time.
+    /// Activity time.
     #[serde(skip_serializing_if = "Option::is_none")]
     pub time: Option<Interval>,
     /// Job tag.
     #[serde(skip_serializing_if = "Option::is_none")]
     pub job_tag: Option<String>,
+    /// Commute information.
+    #[serde(skip_serializing_if = "Option::is_none")]
+    pub commute: Option<Commute>,
 }
 
 /// A stop is a place where vehicle is supposed to be parked.
@@ -79,6 +114,9 @@ pub struct Stop {
     pub distance: i64,
     /// Vehicle load after departure from this stop.
     pub load: Vec<i32>,
+    /// Parking time.
+    #[serde(skip_serializing_if = "Option::is_none")]
+    pub parking: Option<Interval>,
     /// Activities performed at the stop.
     pub activities: Vec<Activity>,
 }
@@ -229,3 +267,52 @@ pub fn serialize_solution<W: Write>(writer: BufWriter<W>, solution: &Solution) -
 pub fn deserialize_solution<R: Read>(reader: BufReader<R>) -> Result<Solution, Error> {
     serde_json::from_reader(reader).map_err(Error::from)
 }
+
+impl Interval {
+    /// Returns interval's duration.
+    pub fn duration(&self) -> Duration {
+        parse_time(&self.end) - parse_time(&self.start)
+    }
+}
+
+impl Default for Timing {
+    fn default() -> Self {
+        Self { driving: 0, serving: 0, waiting: 0, break_time: 0, commuting: 0, parking: 0 }
+    }
+}
+
+impl Commute {
+    /// Creates a new instance of `Commute`.
+    pub fn new(commute: &DomainCommute, start: Timestamp, end: Timestamp, coord_index: &CoordIndex) -> Commute {
+        let parse_info = |info: &DomainCommuteInfo, time: Timestamp| {
+            if info.is_zero_distance() {
+                None
+            } else {
+                Some(CommuteInfo {
+                    location: coord_index.get_by_idx(info.location).expect("commute info has no location"),
+                    distance: info.distance,
+                    time: Interval { start: format_time(time), end: format_time(time + info.duration) },
+                })
+            }
+        };
+
+        Commute { forward: parse_info(&commute.forward, start), backward: parse_info(&commute.backward, end) }
+    }
+
+    /// Converts given commute object to core model.
+    pub(crate) fn to_domain(&self, coord_index: &CoordIndex) -> DomainCommute {
+        let parse_info = |info: &Option<CommuteInfo>| {
+            info.as_ref().map_or(DomainCommuteInfo::default(), |info| {
+                let start = parse_time(&info.time.start);
+                let end = parse_time(&info.time.end);
+                DomainCommuteInfo {
+                    location: coord_index.get_by_loc(&info.location).expect("expect to have coordinate in commute"),
+                    distance: info.distance,
+                    duration: end - start,
+                }
+            })
+        };
+
+        DomainCommute { forward: parse_info(&self.forward), backward: parse_info(&self.backward) }
+    }
+}
