@@ -13,7 +13,7 @@ fn can_assign_interval_break_between_jobs() {
     let problem = Problem {
         plan: Plan {
             jobs: vec![create_delivery_job("job1", vec![5., 0.]), create_delivery_job("job2", vec![15., 0.])],
-            relations: None,
+            ..create_empty_plan()
         },
         fleet: Fleet {
             vehicles: vec![VehicleType {
@@ -43,7 +43,7 @@ fn can_assign_interval_break_between_jobs() {
                 cost: 74.,
                 distance: 30,
                 duration: 34,
-                times: Timing { driving: 30, serving: 2, waiting: 0, break_time: 2 },
+                times: Timing { driving: 30, serving: 2, break_time: 2, ..Timing::default() },
             },
             tours: vec![Tour {
                 vehicle_id: "my_vehicle_1".to_string(),
@@ -66,6 +66,7 @@ fn can_assign_interval_break_between_jobs() {
                         },
                         distance: 5,
                         load: vec![1],
+                        parking: None,
                         activities: vec![
                             Activity {
                                 job_id: "job1".to_string(),
@@ -76,6 +77,7 @@ fn can_assign_interval_break_between_jobs() {
                                     end: "1970-01-01T00:00:06Z".to_string(),
                                 }),
                                 job_tag: None,
+                                commute: None
                             },
                             Activity {
                                 job_id: "break".to_string(),
@@ -86,6 +88,7 @@ fn can_assign_interval_break_between_jobs() {
                                     end: "1970-01-01T00:00:08Z".to_string(),
                                 }),
                                 job_tag: None,
+                                commute: None
                             }
                         ],
                     },
@@ -110,7 +113,7 @@ fn can_assign_interval_break_between_jobs() {
                     cost: 74.,
                     distance: 30,
                     duration: 34,
-                    times: Timing { driving: 30, serving: 2, waiting: 0, break_time: 2 },
+                    times: Timing { driving: 30, serving: 2, break_time: 2, ..Timing::default() },
                 },
             }],
             ..create_empty_solution()
@@ -128,7 +131,7 @@ fn can_assign_interval_break_with_reload() {
                 create_delivery_job("job3", vec![20., 0.]),
                 create_delivery_job("job4", vec![25., 0.]),
             ],
-            relations: None,
+            ..create_empty_plan()
         },
         fleet: Fleet {
             vehicles: vec![VehicleType {
@@ -175,7 +178,7 @@ fn can_assign_interval_break_with_reload() {
                 cost: 139.,
                 distance: 60,
                 duration: 69,
-                times: Timing { driving: 60, serving: 7, waiting: 0, break_time: 2 },
+                times: Timing { driving: 60, serving: 7, break_time: 2, ..Timing::default() },
             },
             tours: vec![Tour {
                 vehicle_id: "my_vehicle_1".to_string(),
@@ -198,6 +201,7 @@ fn can_assign_interval_break_with_reload() {
                         },
                         distance: 10,
                         load: vec![1],
+                        parking: None,
                         activities: vec![
                             Activity {
                                 job_id: "job1".to_string(),
@@ -208,6 +212,7 @@ fn can_assign_interval_break_with_reload() {
                                     end: "1970-01-01T00:00:11Z".to_string(),
                                 }),
                                 job_tag: None,
+                                commute: None
                             },
                             Activity {
                                 job_id: "break".to_string(),
@@ -218,6 +223,7 @@ fn can_assign_interval_break_with_reload() {
                                     end: "1970-01-01T00:00:13Z".to_string(),
                                 }),
                                 job_tag: None,
+                                commute: None
                             }
                         ],
                     },
@@ -266,7 +272,7 @@ fn can_assign_interval_break_with_reload() {
                     cost: 139.,
                     distance: 60,
                     duration: 69,
-                    times: Timing { driving: 60, serving: 7, waiting: 0, break_time: 2 },
+                    times: Timing { driving: 60, serving: 7, break_time: 2, ..Timing::default() },
                 },
             }],
             ..create_empty_solution()
@@ -282,7 +288,7 @@ fn can_consider_departure_rescheduling() {
                 create_delivery_job_with_times("job1", vec![5., 0.], vec![(10, 10)], 1.),
                 create_delivery_job_with_times("job2", vec![10., 0.], vec![(10, 30)], 1.),
             ],
-            relations: None,
+            ..create_empty_plan()
         },
         fleet: Fleet {
             vehicles: vec![VehicleType {
