@@ -11,7 +11,7 @@ fn can_unassign_multi_job_due_to_capacity() {
                 vec![((2., 0.), 1., vec![2]), ((8., 0.), 1., vec![1])],
                 vec![((6., 0.), 1., vec![3])],
             )],
-            relations: Option::None,
+            ..create_empty_plan()
         },
         fleet: Fleet {
             vehicles: vec![create_vehicle_with_capacity("my_vehicle", vec![2])],
@@ -30,7 +30,7 @@ fn can_unassign_multi_job_due_to_capacity() {
                 cost: 0.,
                 distance: 0,
                 duration: 0,
-                times: Timing { driving: 0, serving: 0, waiting: 0, break_time: 0 },
+                times: Timing { driving: 0, serving: 0, ..Timing::default() },
             },
             tours: vec![],
             unassigned: Some(vec![UnassignedJob {
