@@ -1,11 +1,12 @@
 use crate::constraints::BreakModule;
-use crate::extensions::create_typed_actor_groups;
+use crate::core::construction::constraints::ConstraintModule;
+use crate::core::models::problem::Job;
 use crate::helpers::*;
 use std::sync::Arc;
 use vrp_core::construction::constraints::ConstraintPipeline;
 use vrp_core::construction::heuristics::{RouteContext, RouteState, SolutionContext};
 use vrp_core::models::common::{IdDimension, Location, ValueDimension};
-use vrp_core::models::problem::{Fleet, Single};
+use vrp_core::models::problem::Single;
 
 fn create_single(id: &str) -> Arc<Single> {
     let mut single = create_single_with_location(Some(DEFAULT_JOB_LOCATION));
@@ -36,11 +37,7 @@ can_remove_orphan_break! {
 
 fn can_remove_orphan_break_impl(break_job_loc: Option<Location>, break_activity_loc: Location, break_removed: bool) {
     let (transport, _) = get_costs();
-    let fleet = Fleet::new(
-        vec![Arc::new(test_driver())],
-        vec![Arc::new(test_vehicle("v1"))],
-        Box::new(|actors| create_typed_actor_groups(actors)),
-    );
+    let fleet = test_fleet();
     let mut solution_ctx = SolutionContext {
         routes: vec![RouteContext::new_with_state(
             Arc::new(create_route_with_activities(
@@ -77,3 +74,22 @@ fn can_remove_orphan_break_impl(break_job_loc: Option<Location>, break_activity_
         (if break_removed { 4 } else { 5 })
     );
 }
+
+parameterized_test! {can_skip_merge_breaks, (source, candidate, expected), {
+    can_skip_merge_breaks_impl(Job::Single(source), Job::Single(candidate), expected);
+}}
+
+can_skip_merge_breaks! {
+    case_01: (create_single("source"), create_break("v1", None), Err(0)),
+    case_02: (create_break("v1", None), create_single("candidate"), Err(0)),
+    case_03: (create_single("source"), create_single("candidate"), Ok(())),
+}
+
+fn can_skip_merge_breaks_impl(source: Job, candidate: Job, expected: Result<(), i32>) {
+    let (transport, _) = get_costs();
+    let constraint = BreakModule::new(transport, 0);
+
+    let result = constraint.merge(source, candidate).map(|_| ());
+
+    assert_eq!(result, expected);
+}
