@@ -19,7 +19,7 @@ fn create_basic_problem(breaks: Option<Vec<VehicleBreak>>) -> Problem {
                 ),
                 create_pickup_job("job3", vec![5., 0.]),
             ],
-            relations: None,
+            ..create_empty_plan()
         },
         fleet: Fleet {
             vehicles: vec![VehicleType {
@@ -84,7 +84,7 @@ fn can_read_basic_init_solution() {
             cost: 32.,
             distance: 8,
             duration: 14,
-            times: Timing { driving: 8, serving: 4, waiting: 0, break_time: 2 },
+            times: Timing { driving: 8, serving: 4, break_time: 2, ..Timing::default() },
         },
         tours: vec![Tour {
             vehicle_id: "my_vehicle_1".to_string(),
@@ -123,6 +123,7 @@ fn can_read_basic_init_solution() {
                         departure: "1970-01-01T00:00:08Z".to_string(),
                     },
                     distance: 3,
+                    parking: None,
                     load: vec![2],
                     activities: vec![
                         Activity {
@@ -134,6 +135,7 @@ fn can_read_basic_init_solution() {
                                 end: "1970-01-01T00:00:06Z".to_string(),
                             }),
                             job_tag: Some("p2".to_owned()),
+                            commute: None,
                         },
                         Activity {
                             job_id: "break".to_string(),
@@ -144,6 +146,7 @@ fn can_read_basic_init_solution() {
                                 end: "1970-01-01T00:00:08Z".to_string(),
                             }),
                             job_tag: None,
+                            commute: None,
                         },
                     ],
                 },
@@ -169,7 +172,7 @@ fn can_read_basic_init_solution() {
                 cost: 32.,
                 distance: 8,
                 duration: 14,
-                times: Timing { driving: 8, serving: 4, waiting: 0, break_time: 2 },
+                times: Timing { driving: 8, serving: 4, break_time: 2, ..Timing::default() },
             },
         }],
         unassigned: create_unassigned_jobs(&["job3"]),
@@ -183,23 +186,66 @@ fn can_read_basic_init_solution() {
 }
 
 #[test]
-fn can_handle_error_in_init_solution() {
+fn can_handle_empty_tour_error_in_init_solution() {
     let problem = create_basic_problem(create_default_breaks());
     let solution = Solution {
-        statistic: Default::default(),
         tours: vec![Tour {
             vehicle_id: "my_vehicle_1".to_string(),
             type_id: "my_vehicle".to_string(),
-            shift_index: 0,
-            stops: vec![],
-            statistic: Default::default(),
+            ..create_empty_tour()
         }],
-        unassigned: None,
-        violations: None,
-        extras: None,
+        ..create_empty_solution()
     };
 
     let result_solution = get_init_solution(problem, &solution);
 
     assert_eq!(result_solution, Err("empty tour in init solution".to_owned()));
 }
+
+#[test]
+fn can_handle_commute_error_in_init_solution() {
+    let problem = create_basic_problem(None);
+    let solution = Solution {
+        tours: vec![Tour {
+            vehicle_id: "my_vehicle_1".to_string(),
+            type_id: "my_vehicle".to_string(),
+            stops: vec![
+                create_stop_with_activity(
+                    "departure",
+                    "departure",
+                    (0., 0.),
+                    1,
+                    ("1970-01-01T00:00:00Z", "1970-01-01T00:00:00Z"),
+                    0,
+                ),
+                Stop {
+                    location: vec![1., 0.].to_loc(),
+                    time: Schedule {
+                        arrival: "1970-01-01T00:00:01Z".to_string(),
+                        departure: "1970-01-01T00:00:02Z".to_string(),
+                    },
+                    distance: 1,
+                    parking: None,
+                    load: vec![0],
+                    activities: vec![Activity {
+                        job_id: "job1".to_string(),
+                        activity_type: "delivery".to_string(),
+                        location: Some(vec![1., 0.].to_loc()),
+                        time: Some(Interval {
+                            start: "1970-01-01T00:00:01Z".to_string(),
+                            end: "1970-01-01T00:00:02Z".to_string(),
+                        }),
+                        job_tag: None,
+                        commute: Some(Commute { forward: None, backward: None }),
+                    }],
+                },
+            ],
+            ..create_empty_tour()
+        }],
+        ..create_empty_solution()
+    };
+
+    let result_solution = get_init_solution(problem, &solution);
+
+    assert_eq!(result_solution, Err("commute property in initial solution is not supported".to_owned()));
+}
